searchData={"items":[{"type":"module","title":"PlugLocale.Header","doc":"Puts locale into `assigns` storage according to given HTTP request header.\n\n> This is generally used by HTTP API for clients like mobile apps.\n\nBy default, the used HTTP request header is `x-client-locale`. Although\nthere's a standard HTTP header - `accept-language`, but it is better to\nuse a custom header, because it is simpler and has no historical baggage\nto overcome.","ref":"PlugLocale.Header.html"},{"type":"module","title":"Usage - PlugLocale.Header","doc":"First, we need to integrate this plug with other libraries, or this plug\nis useless. All you need is to construct a plug pipeline through\n`Plug.Builder`. For example:\n\n    defmodule DemoWeb.PlugMobileClientLocalization do\n      use Plug.Builder\n\n      plug PlugLocale.Header,\n        default_locale: \"en\",\n        locales: [\"en\", \"zh\"]\n\n      plug :put_locale\n\n      def put_locale(conn, _opts) do\n        if locale = conn.assigns[:locale] do\n          # integrate with gettext\n          Gettext.put_locale(locale)\n        end\n\n        conn\n      end\n    end\n\nThen, use it in router (following one is a Phoenix router, but `Plug.Router`\nis supported, too):\n\n    defmodule DemoWeb.Router do\n      use DemoWeb, :router\n\n      pipeline :api do\n        plug :accepts, [\"json\"]\n\n        # ...\n\n        plug DemoWeb.PlugMobileClientLocalization\n\n        # ...\n      end\n\n      scope \"/\", DemoWeb do\n        pipe_through :api\n\n        get \"/\", PageController, :index\n        # ...\n      end\n    end","ref":"PlugLocale.Header.html#module-usage"},{"type":"module","title":"Options - PlugLocale.Header","doc":"* `:default_locale` - the default locale.\n  * `:locales` - all the supported locales. Default to `[]`.\n  * `:sanitize_locale` - a function for sanitizing extracted or detected\n    locales. Default to `&PlugLocale.Sanitizer.sanitize/1` which does\n    nothing. See `PlugLocale.Sanitizer` for more details.\n  * `:header_name` - the header for getting locale.\n    Default to `\"x-client-locale\"`.\n  * `:assign_key` - the key for putting value into `assigns` storage.\n    Default to `:locale`.","ref":"PlugLocale.Header.html#module-options"},{"type":"module","title":"PlugLocale.Sanitizer","doc":"The default implementation is a function like `fn x -> x end`, which does\nnothing. But, in practice, you will need to use something meaningful.\n\nA possible implementation:\n\n    defmodule DemoWeb.LocaleSanitizer do\n      def sanitize(locale) do\n        case locale do\n          # explicit matching on supported locales\n          locale when locale in [\"en\", \"zh\"] ->\n            locale\n\n          # fuzzy matching on en locale\n          \"en-\" <> _ ->\n            \"en\"\n\n          # fuzzy matching on zh locale\n          \"zh-\" <> _ ->\n            \"zh\"\n\n          # fallback for unsupported locales\n          _ ->\n            \"en\"\n        end\n      end\n    end\n\nThen, use above implementation in plugs by using `:sanitize_locale` option:\n\n    # use it for PlugLocale.WebBrowser\n    plug PlugLocale.WebBrowser,\n      default_locale: \"en\",\n      locales: [\"en\", \"zh\"],\n      sanitize_locale: &DemoWeb.LocaleSanitizer.sanitize/1,\n      # ...\n\n    # use it for PlugLocale.Header\n    plug PlugLocale.Header,\n      default_locale: \"en\",\n      locales: [\"en\", \"zh\"],\n      sanitize_locale: &DemoWeb.LocaleSanitizer.sanitize/1,\n      # ...","ref":"PlugLocale.Sanitizer.html"},{"type":"module","title":"PlugLocale.WebBrowser","doc":"Puts locale into `assigns` storage for Web browser environment.\n\nThe most common way of specifying the desired locale is via the URL. In\ngeneral, there're three methods to do that:\n\n  1. via domain name - `https:// .example.com`, such as:\n     * `https://en.example.com/welcome`\n     * `https://zh.example.com/welcome`\n  2. via path - `https://example.com/ `, such as:\n     * `https://example.com/en/welcome`\n     * `https://example.com/zh/welcome`\n  3. via querystring - `https://example.com?locale= `, such as:\n     * `https://example.com/welcome?locale=en`\n     * `https://example.com/welcome?locale=zh`\n\nPersonally, I think method 2 is better, compared to the other two methods:\n\n  * method 1 is tedious for deployment.\n  * URLs generated by method 3 look very ugly and unprofessional.\n\nBecause of that, this plug will stick on method 2.","ref":"PlugLocale.WebBrowser.html"},{"type":"module","title":"Usage - PlugLocale.WebBrowser","doc":"First, we need to integrate this plug with other libraries, or this plug\nis useless. All you need is to construct a plug pipeline through\n`Plug.Builder`. For example:\n\n    defmodule DemoWeb.PlugWebBrowserLocalization do\n      use Plug.Builder\n    \n      plug PlugLocale.WebBrowser,\n        default_locale: \"en\",\n        locales: [\"en\", \"zh\"],\n        route_identifier: :locale,\n        assign_key: :locale\n    \n      plug :put_locale\n    \n      def put_locale(conn, _opts) do\n        if locale = conn.assigns[:locale] do\n          # integrate with gettext\n          Gettext.put_locale(locale)\n        end\n    \n        conn\n      end\n    end\n\nThen, use it in router (following one is a Phoenix router, but `Plug.Router`\nis supported, too):\n\n    defmodule DemoWeb.Router do\n      use DemoWeb, :router\n    \n      pipeline :browser do\n        plug :accepts, [\"html\"]\n\n        # ...\n\n        plug DemoWeb.PlugWebBrowserLocalization\n\n        # ...\n      end\n    \n      scope \"/\", DemoWeb do\n        pipe_through :browser\n\n        get \"/\", PageController, :index\n        # ...\n      end\n\n      # Why using :locale?\n      # Because it is specified by `:route_identifier` option.\n      scope \"/:locale\", DemoWeb do\n        pipe_through :browser\n\n        get \"/\", PageController, :index\n        # ...\n      end\n    end","ref":"PlugLocale.WebBrowser.html#module-usage"},{"type":"module","title":"Options - PlugLocale.WebBrowser","doc":"* `:default_locale` - the default locale.\n  * `:locales` - all the supported locales. Default to `[]`.\n  * `:sanitize_locale` - a function for sanitizing extracted or detected\n    locales. Default to `&PlugLocale.Sanitizer.sanitize/1` which does\n    nothing. See `PlugLocale.Sanitizer` for more details.\n  * `:route_identifier` - the part for identifying locale in route.\n    Default to `:locale`.\n  * `:assign_key` - the key for putting value into `assigns` storage.\n    Default to the value of `:route_identifier` option.\n  * `:cookie_key` - the key for reading locale from cookie.\n    Default to `\"preferred_locale\"`.","ref":"PlugLocale.WebBrowser.html#module-options"},{"type":"module","title":"How it works? - PlugLocale.WebBrowser","doc":"This plug will try to:\n\n  1. extract locale from URL, and check if the locale is supported:\n     - If it succeeds, put locale into `assigns` storage。\n     - If it fails, jump to step 2.\n  2. detect locale from Web browser environment, then redirect to\n     the path corresponding to detected locale.\n\n#","ref":"PlugLocale.WebBrowser.html#module-how-it-works"},{"type":"module","title":"Extract locale from URL - PlugLocale.WebBrowser","doc":"For example, the locale extracted from `https://example.com/en/welcome`\nis `en`.\n\n#","ref":"PlugLocale.WebBrowser.html#module-extract-locale-from-url"},{"type":"module","title":"Detect locale from Web browser environment - PlugLocale.WebBrowser","doc":"Local is detected from multiple places:\n\n  * cookie (whose key is specified by `:cookie_key` option)\n  * HTTP request header - `referer`\n  * HTTP request header - `accept-language`\n  * default locale (which is specified by `:default_locale` option)","ref":"PlugLocale.WebBrowser.html#module-detect-locale-from-web-browser-environment"},{"type":"module","title":"Examples - PlugLocale.WebBrowser","doc":"When:\n\n  * `:default_locale` option is set to `\"en\"`\n  * `:locales` option is set to `[\"en\", \"zh\"]`\n\nFor users in an English-speaking environment:\n\n  * `https://example.com/en` will be responded directly.\n  * `https://example.com/` will be redirected to `https://example.com/en`.\n  * `https://example.com/path` will be redirected to `https://example.com/en/path`.\n  * `https://example.com/unknown` will be redirected to `https://example.com/en`.\n  * ...\n\nFor users in an Chinese-speaking environment:\n\n  * `https://example.com/zh` will be responded directly.\n  * `https://example.com/` will be redirected to `https://example.com/zh`.\n  * `https://example.com/path` will be redirected to `https://example.com/zh/path`.\n  * `https://example.com/unknown` will be redirected to `https://example.com/zh`.\n  * ...","ref":"PlugLocale.WebBrowser.html#module-examples"},{"type":"function","title":"PlugLocale.WebBrowser.redirect_to/2","doc":"","ref":"PlugLocale.WebBrowser.html#redirect_to/2"},{"type":"extras","title":"PlugLocale","doc":"# PlugLocale\n\n[![CI](https://github.com/cozy-elixir/plug_locale/actions/workflows/ci.yml/badge.svg)](https://github.com/cozy-elixir/plug_locale/actions/workflows/ci.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/plug_locale.svg)](https://hex.pm/packages/plug_locale)\n[![built with Nix](https://img.shields.io/badge/built%20with%20Nix-5277C3?logo=nixos&logoColor=white)](https://builtwithnix.org)\n\nPlugs for putting locale into `assigns` storage.","ref":"readme.html"},{"type":"extras","title":"Installation - PlugLocale","doc":"Add `:plug_locale` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:plug_locale,  }\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - PlugLocale","doc":"Different from [`set_locale`](https://hex.pm/packages/set_locale), [`ex_cldr_plugs`](https://hex.pm/packages/ex_cldr_plugs), etc, `plug_locale`:\n\n- only does one simple thing - setting a locale-related assign (by default, it is `conn.assigns.locale`).\n- does not make any assumptions about the localization strategy, so it is not tightly bound to packages like [`gettext`](https://hex.pm/packages/gettext) or [`ex_cldr`](https://hex.pm/packages/ex_cldr).\n\nCheck out `PlugLocale.WebBrowser`, `PlugLocale.Header` in [documentation](https://hexdocs.pm/plug_locale) for more details.","ref":"readme.html#usage"},{"type":"extras","title":"Thanks - PlugLocale","doc":"This library is built on the wisdom in following code:\n\n- [`set_locale`](https://hex.pm/packages/set_locale)","ref":"readme.html#thanks"},{"type":"extras","title":"License - PlugLocale","doc":"Apache License 2.0","ref":"readme.html#license"}],"content_type":"text/markdown"}